#!/bin/sh

NAME="daware-mod"
VERSION="1.1"

dkms_status()
{
    echo `dkms status -m ${NAME} -v ${VERSION} | sed 's/^.*: \(.*\)$/\1/'`
}

if [ $(id -u) != '0' ]
then
    echo "Permission denied."
    exit 1
fi

DISTRIBUTION=`lsb_release -is`

if [ "${DISTRIBUTION}" != "Ubuntu" -a "${DISTRIBUTION}" != "CentOS" ]
then
    echo "Bad Distribution."
    exit 2
fi

if [ "`dkms_status`" = 'installed' ]
then
    echo "${NAME}-${VERSION} already installed."
fi

if [ -z "`dkms_status`" ]
then
    dkms add -m ${NAME} -v ${VERSION}
fi

if [ "`dkms_status`" = 'added' ]
then
    if [ "${DISTRIBUTION}" = "Ubuntu" ]
    then
        headers="linux-headers-`uname -r`"
        if [ -z "`dpkg -l | grep ${headers}`" ]
        then
            apt-get install -y ${headers}
        fi
    else    # CentOS
        headers="kernel-devel"
        if [ -z "`rpm -qa | grep ${headers}`" ]
        then
            yum install -y ${headers}
        fi
    fi
fi

if [ "`dkms_status`" = 'added' ]
then
    if [ "${DISTRIBUTION}" = "Ubuntu" ]
    then
        dkms build -m ${NAME} -v ${VERSION}
    else    # CentOS
        DIR=`ls -1 /usr/src/kernels | head -1`
        dkms build -m ${NAME} -v ${VERSION} --kernelsourcedir /usr/src/kernels/$DIR
    fi
fi

if [ "`dkms_status`" = 'built' ]
then
    dkms install -m ${NAME} -v ${VERSION}
fi

mod_dir="/lib/modules/`uname -r`"

if [ -z "`grep 'daware.ko' ${mod_dir}/modules.dep`" ]
then
    depmod -a
fi

if [ -z "`lsmod | grep daware`" ]
then
    modprobe daware
fi

exit 0
